Book One

# Document One of Infinity

By: Mark Horner , Sarah Blyth and Charmaine St. Rose Edited by: I. M. Picky Illustrated by: Francis Hablar Translated by: Francis Hablar
Published By: Ream
Based on: Wild Grains and Warted Feet

Copyright: Ream

Licensed: CC-By 4.0

By the end of this section, you will be able to:

- Drive a car
- Purchase a watch
- Wear funny hats
- Eat cake

Physics
South Africa
Science and Mathematics